@@ -116,6 +116,10 @@ class Dataset(torch.utils.data.Dataset):
     def dtype(self):
         return self.__dtype
 
+    @property
+    def idx_data(self):
+        return [d.idx for d in self.data]
+
     @property
     def tooltips(self):
         return [d.tooltip for d in self.data]
