@@ -166,6 +166,7 @@ def k_fold_cross_validation(k_folds: list,
                             n_epochs: int = 300,
                             random_seed: int = 0):
     scores = list()
+    idx_test = list()
     preds = list()
     targets = list()
     tooltips = list()
@@ -204,12 +205,14 @@ def k_fold_cross_validation(k_folds: list,
         else:
             raise KeyError('Unknown source library \'{}\' of the prediction model.'.format(model.alg_src))
 
+        idx_test.append(dataset_test.idx_data)
         preds.append(preds_test)
         targets.append(dataset_test.y)
         tooltips.append(dataset_test.tooltips)
 
     preds = torch.vstack(preds)
     targets = torch.vstack(targets)
+    eval_results['idx_test'] = flatten_lists(idx_test)
     eval_results['preds_test'] = preds.flatten().tolist()
     eval_results['targets_test'] = targets.flatten().tolist()
     eval_results['tooltips_test'] = flatten_lists(tooltips)
